mod api;
mod hello;

use crate::{app_state::AppState, config::Config, model::instance::Instance};
use axum::{routing::post, Extension, Router};
use sqlx::{Pool, Postgres};
use std::sync::Arc;
use tower_http::trace::TraceLayer;

pub fn new(pool: Pool<Postgres>, config: Config, instance: Instance) -> Router {
    let app_state = Arc::new(AppState {
        pool,
        config,
        public_key: instance.public_key,
        private_key: instance.private_key,
    });

    let app = Router::new()
        .route("/_fox/chat/hello", post(hello::post_hello))
        .merge(api::router())
        .layer(TraceLayer::new_for_http())
        .layer(Extension(app_state));

    return app;
}
